Stan Math Library: std::numeric_limits< stan::math::fvar< T > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | Static Public Attributes | List of all members
std::numeric_limits< stan::math::fvar< T > > Struct Template Reference

`#include <std_numeric_limits.hpp>`

## Static Public Member Functions
static stan::math::fvar< T > | min ()
static stan::math::fvar< T > | max ()
static stan::math::fvar< T > | epsilon ()
static stan::math::fvar< T > | round_error ()
static stan::math::fvar< T > | infinity ()
static stan::math::fvar< T > | quiet_NaN ()
static stan::math::fvar< T > | signaling_NaN ()
static stan::math::fvar< T > | denorm_min ()

## Static Public Attributes
static const bool | is_specialized = true
static const int | digits = numeric_limits<double>::digits
static const int | digits10 = numeric_limits<double>::digits10
static const bool | is_signed = numeric_limits<double>::is_signed
static const bool | is_integer = numeric_limits<double>::is_integer
static const bool | is_exact = numeric_limits<double>::is_exact
static const int | radix = numeric_limits<double>::radix
static const int | min_exponent = numeric_limits<double>::min_exponent
static const int | min_exponent10 = numeric_limits<double>::min_exponent10
static const int | max_exponent = numeric_limits<double>::max_exponent
static const int | max_exponent10 = numeric_limits<double>::max_exponent10
static const bool | has_infinity = numeric_limits<double>::has_infinity
static const bool | has_quiet_NaN = numeric_limits<double>::has_quiet_NaN
static const bool | has_signaling_NaN
static const float_denorm_style | has_denorm
static const bool | has_denorm_loss = numeric_limits<double>::has_denorm_loss
static const bool | is_iec559 = numeric_limits<double>::is_iec559
static const bool | is_bounded = numeric_limits<double>::is_bounded
static const bool | is_modulo = numeric_limits<double>::is_modulo
static const bool | traps = numeric_limits<double>::traps
static const bool | tinyness_before = numeric_limits<double>::tinyness_before
static const float_round_style | round_style

## Detailed Description

### template<typename T>
struct std::numeric_limits< stan::math::fvar< T > >

Definition at line 11 of file std_numeric_limits.hpp.

## Member Function Documentation

template<typename T >

static stan::math::fvar<T> std::numeric_limits< stan::math::fvar< T > >::denorm_min | ( |  | ) |
| inlinestatic

Definition at line 44 of file std_numeric_limits.hpp.

template<typename T >

static stan::math::fvar<T> std::numeric_limits< stan::math::fvar< T > >::epsilon | ( |  | ) |
| inlinestatic

Definition at line 21 of file std_numeric_limits.hpp.

template<typename T >

static stan::math::fvar<T> std::numeric_limits< stan::math::fvar< T > >::infinity | ( |  | ) |
| inlinestatic

Definition at line 38 of file std_numeric_limits.hpp.

template<typename T >

static stan::math::fvar<T> std::numeric_limits< stan::math::fvar< T > >::max | ( |  | ) |
| inlinestatic

Definition at line 14 of file std_numeric_limits.hpp.

template<typename T >

static stan::math::fvar<T> std::numeric_limits< stan::math::fvar< T > >::min | ( |  | ) |
| inlinestatic

Definition at line 13 of file std_numeric_limits.hpp.

template<typename T >

static stan::math::fvar<T> std::numeric_limits< stan::math::fvar< T > >::quiet_NaN | ( |  | ) |
| inlinestatic

Definition at line 40 of file std_numeric_limits.hpp.

template<typename T >

static stan::math::fvar<T> std::numeric_limits< stan::math::fvar< T > >::round_error | ( |  | ) |
| inlinestatic

Definition at line 23 of file std_numeric_limits.hpp.

template<typename T >

static stan::math::fvar<T> std::numeric_limits< stan::math::fvar< T > >::signaling_NaN | ( |  | ) |
| inlinestatic

Definition at line 42 of file std_numeric_limits.hpp.

## Member Data Documentation

template<typename T >

const int std::numeric_limits< stan::math::fvar< T > >::digits = numeric_limits<double>::digits
| static

Definition at line 15 of file std_numeric_limits.hpp.

template<typename T >

const int std::numeric_limits< stan::math::fvar< T > >::digits10 = numeric_limits<double>::digits10
| static

Definition at line 16 of file std_numeric_limits.hpp.

template<typename T >

const float_denorm_style std::numeric_limits< stan::math::fvar< T > >::has_denorm
| static

Initial value:
=
numeric_limits<double>::has_denorm

Definition at line 35 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::has_denorm_loss = numeric_limits<double>::has_denorm_loss
| static

Definition at line 37 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::has_infinity = numeric_limits<double>::has_infinity
| static

Definition at line 31 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::has_quiet_NaN = numeric_limits<double>::has_quiet_NaN
| static

Definition at line 32 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::has_signaling_NaN
| static

Initial value:
=
numeric_limits<double>::has_signaling_NaN

Definition at line 33 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::is_bounded = numeric_limits<double>::is_bounded
| static

Definition at line 48 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::is_exact = numeric_limits<double>::is_exact
| static

Definition at line 19 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::is_iec559 = numeric_limits<double>::is_iec559
| static

Definition at line 47 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::is_integer = numeric_limits<double>::is_integer
| static

Definition at line 18 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::is_modulo = numeric_limits<double>::is_modulo
| static

Definition at line 49 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::is_signed = numeric_limits<double>::is_signed
| static

Definition at line 17 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::is_specialized = true
| static

Definition at line 12 of file std_numeric_limits.hpp.

template<typename T >

const int std::numeric_limits< stan::math::fvar< T > >::max_exponent = numeric_limits<double>::max_exponent
| static

Definition at line 28 of file std_numeric_limits.hpp.

template<typename T >

const int std::numeric_limits< stan::math::fvar< T > >::max_exponent10 = numeric_limits<double>::max_exponent10
| static

Definition at line 29 of file std_numeric_limits.hpp.

template<typename T >

const int std::numeric_limits< stan::math::fvar< T > >::min_exponent = numeric_limits<double>::min_exponent
| static

Definition at line 26 of file std_numeric_limits.hpp.

template<typename T >

const int std::numeric_limits< stan::math::fvar< T > >::min_exponent10 = numeric_limits<double>::min_exponent10
| static

Definition at line 27 of file std_numeric_limits.hpp.

template<typename T >

const int std::numeric_limits< stan::math::fvar< T > >::radix = numeric_limits<double>::radix
| static

Definition at line 20 of file std_numeric_limits.hpp.

template<typename T >

const float_round_style std::numeric_limits< stan::math::fvar< T > >::round_style
| static

Initial value:
=
numeric_limits<double>::round_style

Definition at line 53 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::tinyness_before = numeric_limits<double>::tinyness_before
| static

Definition at line 52 of file std_numeric_limits.hpp.

template<typename T >

const bool std::numeric_limits< stan::math::fvar< T > >::traps = numeric_limits<double>::traps
| static

Definition at line 51 of file std_numeric_limits.hpp.

The documentation for this struct was generated from the following file:

- stan/math/fwd/core/std_numeric_limits.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.